BarcodeClassicScannerConfiguration class

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false, explicitToJson: true)

Constructors

BarcodeClassicScannerConfiguration({List<BarcodeFormatConfigurationBase>? barcodeFormatConfigurations = null, List<BarcodeDocumentFormat>? acceptedDocumentFormats = null, bool? onlyAcceptDocuments = null, BarcodeAccumulationConfiguration? accumulationConfig = null, BarcodeScannerEngineMode? engineMode = BarcodeScannerEngineMode.NEXT_GEN, bool? returnBarcodeImage})

Properties

acceptedDocumentFormats ↔ List<BarcodeDocumentFormat>?
List of accepted Document Formats; any document formats that are not included in this list will be ignored by the BarcodeCameraView. By default, the list includes all supported document types.
getter/setter pair
accumulationConfig ↔ BarcodeAccumulationConfiguration?
Configuration to accumulate barcodes across multiple frames in live mode.
getter/setter pair
barcodeFormatConfigurations ↔ List<BarcodeFormatConfigurationBase>?
List of accepted Barcode Formats; any formats that are not included in this list will not be detected by the BarcodeCameraView. By default, the list includes all supported barcode types.
getter/setter pair
detectorType → DetectorType
final
engineMode ↔ BarcodeScannerEngineMode?
The engine mode of the barcode recognizer. Defaults to NEXT_GEN. To use legacy recognizer, please specify LEGACY
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onlyAcceptDocuments ↔ bool?
getter/setter pair
returnBarcodeImage ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited