BarcodeItemOverlayViewConfig class

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false, explicitToJson: true)

Constructors

BarcodeItemOverlayViewConfig.create(BarcodeItem item, {String? text, BarcodeOverlayTextFormat? textFormat, Color? polygonColor, Color? strokeColor, Color? highlightedPolygonColor, Color? highlightedStrokeColor, Color? textColor, Color? textContainerColor, Color? highlightedTextColor, Color? highlightedTextContainerColor})
Creates a view config with optional custom styles.
factory
BarcodeItemOverlayViewConfig.defaultStyle(BarcodeItem item)
Creates a view config with default styles.
factory

Properties

barcodeUuid → String
Unique identifier based on barcode content and format.
final
hashCode → int
The hash code for this object.
no setterinherited
highlightedPolygonColor → Color?
final
highlightedStrokeColor → Color?
final
highlightedTextColor → Color?
final
highlightedTextContainerColor → Color?
final
polygonColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color?
final
text → String?
final
textColor → Color?
final
textContainerColor → Color?
final
textFormat → BarcodeOverlayTextFormat?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited