SelectionOverlayScannerConfiguration class

Barcode Selection Overlay configuration

Annotations
  • @JsonSerializable.new(includeIfNull: false, createFactory: false)

Constructors

SelectionOverlayScannerConfiguration({bool overlayEnabled = true, BarcodeOverlayTextFormat? textFormat = BarcodeOverlayTextFormat.CODE_AND_TYPE, Color? polygonColor = null, Color? strokeColor = null, Color? highlightedPolygonColor = null, Color? highlightedStrokeColor = null, Color? textColor = null, Color? textContainerColor = null, Color? highlightedTextColor = null, Color? highlightedTextContainerColor = null, dynamic onBarcodeTap(BarcodeItem item, bool highlighted)?, String? loadingText, Future<List<BarcodeItemOverlayViewConfig>> barcodeItemOverlayViewBinder(List<BarcodeItem> barcodeItems)?})

Properties

barcodeItemOverlayViewBinder ↔ Future<List<BarcodeItemOverlayViewConfig>> Function(List<BarcodeItem> barcodeItems)?
Callback that configures the selection overlay for each barcode item individually
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highlightedPolygonColor ↔ Color?
Default: #C81A3C33 (ARGB: 200, 26, 60, 51)
getter/setter pair
highlightedStrokeColor ↔ Color?
Default: #C81A3CCC (ARGB: 200, 26, 60, 204)
getter/setter pair
highlightedTextColor ↔ Color?
Default: #00000000 (ARGB: 0, 0, 0, 0)
getter/setter pair
highlightedTextContainerColor ↔ Color?
Default: #C81A3CCC (ARGB: 200, 26, 60, 204)
getter/setter pair
loadingText ↔ String?
Only used if the barcodeItemOverlayViewBinder callback is set
getter/setter pair
onBarcodeTap ↔ dynamic Function(BarcodeItem item, bool highlighted)?
getter/setter pair
overlayEnabled ↔ bool
Whether the barcode selection overlay is enabled or not.
getter/setter pair
polygonColor ↔ Color?
Default: #00CFA633 (ARGB: 0, 207, 166, 51)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor ↔ Color?
Default: #00CFA6CC (ARGB: 0, 207, 166, 204)
getter/setter pair
textColor ↔ Color?
Default: #C81A3CCC (ARGB: 200, 26, 60, 204)
getter/setter pair
textContainerColor ↔ Color?
Default: #00CFA6CC (ARGB: 0, 207, 166, 204)
getter/setter pair
textFormat ↔ BarcodeOverlayTextFormat?
Define the way of how to show barcode data with selection overlay.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited