AAMVA class

AAMVA

Inheritance

Constructors

AAMVA(GenericDocument document)

Properties

document → GenericDocument
finalinherited
driverLicense → AAMVADriverLicense?
The child document of type "DriverLicense".
no setter
enhancedDriverLicense → AAMVAEnhancedDriverLicense?
The child document of type "EnhancedDriverLicense".
no setter
hashCode → int
The hash code for this object.
no setterinherited
idCard → AAMVAIDCard?
The child document of type "IDCard".
no setter
issuerIdentificationNumber → TextFieldWrapper
Issuer Identification Number
no setter
jurisdictionVersionNumber → TextFieldWrapper?
Jurisdiction Version Number
no setter
motorCarrierData → AAMVAMotorCarrierData?
The child document of type "MotorCarrierData".
no setter
rawDocument → AAMVARawDocument
The child document of type "RawDocument".
no setter
registrantAndVehicleData → AAMVARegistrantAndVehicleData?
The child document of type "RegistrantAndVehicleData".
no setter
registrationData → AAMVARegistrationData?
The child document of type "RegistrationData".
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleData → AAMVATitleData?
The child document of type "TitleData".
no setter
vehicleData → AAMVAVehicleData?
The child document of type "VehicleData".
no setter
vehicleOwnerData → AAMVAVehicleOwnerData?
The child document of type "VehicleOwnerData".
no setter
vehicleSafetyInspectionData → AAMVAVehicleSafetyInspectionData?
The child document of type "VehicleSafetyInspectionData".
no setter
version → TextFieldWrapper
Version
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.