AAMVARegistrationData class

Registration Data. File type "RG".

Inheritance

Constructors

AAMVARegistrationData(GenericDocument document)

Properties

addressCity → TextFieldWrapper?
Data element ID "RBK". City portion of the owner’s address.
no setter
addressJurisdictionCode → TextFieldWrapper?
Data element ID "RBL". Jurisdiction portion of the owner’s address.
no setter
addressStreet → TextFieldWrapper?
Data element ID "RBI". Street portion of the owner’s address.
no setter
addressZipCode → TextFieldWrapper?
Data element ID "RBM". The Zip code or Postal code of the vehicle owner’s residence address.
no setter
axles → TextFieldWrapper?
Data element ID "VBC". The number of common axles of rotation of one or more wheels of a vehicle, whether power driven or freely rotating.
no setter
businessName → TextFieldWrapper?
Data element ID "BBC". The business name of the first registrant of a vehicle.
no setter
document → GenericDocument
finalinherited
fuel → TextFieldWrapper?
Data element ID "FUL". The type of fuel used by the vehicle. In most cases, the fuel type would be diesel.
no setter
grossVehicleWeight → TextFieldWrapper?
Data element ID "VAT". The unladen weight of the vehicle (e.g., the single-unit truck, truck combination) plus the weight of the load being carried at a specific point in time.
no setter
hashCode → int
The hash code for this object.
no setterinherited
registrantFamilyName → TextFieldWrapper?
Data element ID "RBD". Family name (commonly called surname or last name) of the registered owner of a vehicle.
no setter
registrantGivenName → TextFieldWrapper?
Data element ID "RBE". Given name or names (includes all of what are commonly referred to as first and middle names) of the registered owner of a vehicle.
no setter
registrationExpiryDate → TextFieldWrapper?
Data element ID "RAG". The date in which the registration expired. The format is ISO8601 with delimiters.
no setter
registrationIssueDate → TextFieldWrapper?
Data element ID "RBB". The date in which the registration was issued. The format is ISO8601 with delimiters.
no setter
registrationPlateNumber → TextFieldWrapper?
Data element ID "RAM". The characters assigned to a registration plate or tag affixed to the vehicle, assigned by the jurisdiction.
no setter
registrationWindowStickerDecal → TextFieldWrapper?
Data element ID "RBU". A unique number printed on the tab/decal and stored as part of the registration record.
no setter
registrationYear → TextFieldWrapper?
Data element ID "RBT". The year of registration.
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vehicleBodyStyle → TextFieldWrapper?
Data element ID "VAO". The general configuration or shape of a vehicle distinguished by characteristics such as number of doors, seats, windows, roofline, and type of top. The vehicle body type is 2-character alphanumeric.
no setter
vehicleColor → TextFieldWrapper?
Data element ID "VBD". Where the vehicle is one color, this is the appropriate code describing that color. When the vehicle is two colors, this is the code for the top-most or front-most color.
no setter
vehicleIdentificationNumber → TextFieldWrapper?
Data element ID "VAD". A unique combination of alphanumeric characters that identifies a specific vehicle or component. The VIN is affixed to the vehicle in specific locations and formulated by the manufacturer. State agencies under some controlled instances my assign a VIN to a vehicle.
no setter
vehicleMake → TextFieldWrapper?
Data element ID "VAK". The distinctive (coded) name applied to a group of vehicles by a manufacturer.
no setter
vehicleModel → TextFieldWrapper?
Data element ID "VAM". A code denoting a family of vehicles (within a make), which has a degree of similarity in construction, such as body, chassis, etc. The field does not necessarily contain a standard code; it may contain a value provided by the originator of the field.
no setter
vehicleModelYear → TextFieldWrapper?
Data element ID "VAL". The year which is assigned to a vehicle by the manufacturer. The format is CCYY.
no setter
vehicleUse → TextFieldWrapper?
Data element ID "VPC". Indicates the use of the vehicle.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.