AAMVAVehicleOwnerData class

Vehicle Owner Data. File type "OW".

Inheritance

Constructors

AAMVAVehicleOwnerData(GenericDocument document)

Properties

document → GenericDocument
finalinherited
firstOwnerIdNumber → TextFieldWrapper?
Data element ID "NAX". The unique customer number/ID of the first vehicle owner.
no setter
firstOwnerLastName → TextFieldWrapper?
Data element ID "NAB". Last Name or Surname of the Owner. Hyphenated names acceptable, spaces between names acceptable, but no other use of special symbols.
no setter
firstOwnerLegalStatus → TextFieldWrapper?
Data element ID "NBA". The legal status of the first vehicle owner. This is only used when a vehicle has multiple owners. A legal status may be ("AND", "OR").
no setter
firstOwnerMiddleName → TextFieldWrapper?
Data element ID "NAD". Middle Name(s) or Initial(s) of the Owner. Hyphenated names acceptable, spaces, between names acceptable, but no other use of special symbols.
no setter
firstOwnerName → TextFieldWrapper?
Data element ID "NAC". First Name or Given Name of the Owner. Hyphenated names acceptable, but no other use of special symbols.
no setter
firstOwnerTotalName → TextFieldWrapper?
Data element ID "NAA". Name of the (or one of the) individual(s) who owns the Vehicle as defined in the ANSI D- 20 Data Element Dictionary. (Lastname@Firstname@MI@Suffix if any.)
no setter
hashCode → int
The hash code for this object.
no setterinherited
mailingAddress1 → TextFieldWrapper?
Data element ID "NAR". Street address line 1. (Mailing)
no setter
mailingAddress2 → TextFieldWrapper?
Data element ID "NAS". Street address line 2. (Mailing)
no setter
mailingCity → TextFieldWrapper?
Data element ID "NAT". Name of city for mailing address.
no setter
mailingJurisdictionCode → TextFieldWrapper?
Data element ID "NAU". Jurisdiction code for mailing address. Conforms to Canadian, Mexican and US jurisdictions as appropriate. Codes for provinces (Canada) and states (US and Mexico).
no setter
mailingZipCode → TextFieldWrapper?
Data element ID "NAV". The ZIP code or Postal code used for mailing. (As used by Canadian, Mexican and US jurisdictions.)
no setter
requiredDocumentType → String
no setteroverride
residenceAddress1 → TextFieldWrapper?
Data element ID "NAM". Street address line 1. (Mailing)
no setter
residenceAddress2 → TextFieldWrapper?
Data element ID "NAN". Street address line 2. (Mailing)
no setter
residenceCity → TextFieldWrapper?
Data element ID "NAO". Name of city for mailing address.
no setter
residenceJurisdictionCode → TextFieldWrapper?
Data element ID "NAP". Jurisdiction code for mailing address. Conforms to Canadian, Mexican and US jurisdictions as appropriate. Codes for provinces (Canada) and states (US and Mexico).
no setter
residenceZipCode → TextFieldWrapper?
Data element ID "NAQ". The ZIP code or Postal code used for mailing. (As used by Canadian, Mexican and US jurisdictions).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondOwnerIdNumber → TextFieldWrapper?
Data element ID "NAY". The unique customer number/ID of the second vehicle owner.
no setter
secondOwnerLastName → TextFieldWrapper?
Data element ID "NAF". Last Name or Surname of the Owner. Hyphenated names acceptable, spaces between names acceptable, but no other use of special symbols.
no setter
secondOwnerLegalStatus → TextFieldWrapper?
Data element ID "NBB". The legal status of the second vehicle owner. This is only used when a vehicle has multiple owners. A legal status may be ("AND", "OR").
no setter
secondOwnerMiddleName → TextFieldWrapper?
Data element ID "NAH". Middle Name(s) or Initial(s) of the Owner. Hyphenated names acceptable, spaces between names acceptable, but no other use of special symbols.
no setter
secondOwnerName → TextFieldWrapper?
Data element ID "NAG". First Name or Given Name of the Owner. Hyphenated names acceptable, but no other use of special symbols.
no setter
secondOwnerTotalName → TextFieldWrapper?
Data element ID "NAE". Name of the (or one of the) individual(s) who owns the Vehicle as defined in the ANSI D- 20 Data Element Dictionary. (Lastname@Firstname@MI@Suffix if any.)
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.