AspectRatio class

Aspect ratio is the ratio of the width to the height of an image or screen.

Constructors

AspectRatio({double width = 1.0, double height = 1.0})
AspectRatio.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
Height component of the aspect ratio.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Width component of the aspect ratio.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited