BarcodeFormats class

Lists of barcode formats to decode.

Constructors

BarcodeFormats()
BarcodeFormats.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

all → List<BarcodeFormat>
List of all barcode formats.
final
common → List<BarcodeFormat>
List of common barcode formats.
final
oned → List<BarcodeFormat>
List of 1D barcode formats.
final
pharma → List<BarcodeFormat>
List of pharmaceutical barcode formats.
final
postal → List<BarcodeFormat>
List of postal barcode formats.
final
twod → List<BarcodeFormat>
List of 2D barcode formats.
final