BoardingPass class

Boarding Pass

Inheritance

Constructors

BoardingPass(GenericDocument document)

Properties

document → GenericDocument
finalinherited
electronicTicketIndicator → TextFieldWrapper
Electronic Ticket
no setter
formatCode → TextFieldWrapper
Format Code.
no setter
hashCode → int
The hash code for this object.
no setterinherited
legs → List<BoardingPassLeg>
A list of all children of type "Leg".
no setter
numberOfLegs → TextFieldWrapper
Number of encoded legs.
no setter
passengerName → TextFieldWrapper
Passenger Name
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityData → TextFieldWrapper?
Security Data
no setter
securityDataType → TextFieldWrapper?
Security Data Type
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.