BufferImageLoadOptions class

Options for loading image from buffer.

Constructors

BufferImageLoadOptions({Rectangle<int>? roi, BufferLoadMode loadMode = BufferLoadMode.EAGER})
BufferImageLoadOptions.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
loadMode ↔ BufferLoadMode
Load mode.
getter/setter pair
roi ↔ Rectangle<int>
Region of interest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited