DEMedicalPlanDoctor class

Doctor

Inheritance

Constructors

DEMedicalPlanDoctor(GenericDocument document)

Properties

doctorNumber → TextFieldWrapper?
Doctor Number
no setter
document → GenericDocument
finalinherited
email → TextFieldWrapper?
Email
no setter
hashCode → int
The hash code for this object.
no setterinherited
hospitalID → TextFieldWrapper?
Hospital ID
no setter
issuerName → TextFieldWrapper?
Issuer Name
no setter
issuingDateAndTime → TextFieldWrapper?
Issuing Date And Time
no setter
pharmacyID → TextFieldWrapper?
Pharmacy ID
no setter
place → TextFieldWrapper?
Place
no setter
postalCode → TextFieldWrapper?
Postal Code
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
street → TextFieldWrapper?
Street
no setter
telephoneNumber → TextFieldWrapper?
Telephone Number
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.