DEMedicalPlanPatient class

Patient

Inheritance

Constructors

DEMedicalPlanPatient(GenericDocument document)

Properties

allergiesAndIntolerances → TextFieldWrapper?
Allergies And Intolerances
no setter
birthDate → TextFieldWrapper?
Birth Date
no setter
breastFeeding → TextFieldWrapper?
Breast Feeding
no setter
creatinineValue → TextFieldWrapper?
Creatinine Value
no setter
document → GenericDocument
finalinherited
firstName → TextFieldWrapper?
First Name
no setter
gender → TextFieldWrapper?
Gender
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → TextFieldWrapper?
Height
no setter
lastName → TextFieldWrapper?
Last Name
no setter
patientFreeText → TextFieldWrapper?
Patient Free Text
no setter
patientID → TextFieldWrapper?
Patient ID
no setter
pregnant → TextFieldWrapper?
Pregnant
no setter
preName → TextFieldWrapper?
Pre Name
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → TextFieldWrapper?
Name Suffix
no setter
title → TextFieldWrapper?
Title
no setter
weight → TextFieldWrapper?
Weight
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.