DEMedicalPlanSubheading class

Subheading

Inheritance

Constructors

DEMedicalPlanSubheading(GenericDocument document)

Properties

document → GenericDocument
finalinherited
generalNotes → List<TextFieldWrapper>
General Note
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyWords → TextFieldWrapper?
Key Words
no setter
medicines → List<DEMedicalPlanSubheadingMedicine>
A list of all children of type "Medicine".
no setter
prescriptions → List<DEMedicalPlanSubheadingPrescription>
A list of all children of type "Prescription".
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subheadingFreeText → TextFieldWrapper?
Subheading Free Text
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.