DEMedicalPlanSubheadingMedicine class

Medicine

Inheritance

Properties

document → GenericDocument
finalinherited
dosageForm → TextFieldWrapper?
Dosage Form
no setter
dosageFormFreeText → TextFieldWrapper?
Dosage Form Free Text
no setter
dosageFreeText → TextFieldWrapper?
Dosage Free Text
no setter
dosingUnit → TextFieldWrapper?
Dosing Unit
no setter
dosingUnitFreeText → TextFieldWrapper?
Dosing Unit Free Text
no setter
drugName → TextFieldWrapper?
Drug Name
no setter
evening → TextFieldWrapper?
Evening Intake Dose
no setter
generalNotes → TextFieldWrapper?
General Notes
no setter
hashCode → int
The hash code for this object.
no setterinherited
midday → TextFieldWrapper?
Midday Intake Dose
no setter
morning → TextFieldWrapper?
Morning Intake Dose
no setter
night → TextFieldWrapper?
Night Intake Dose
no setter
pharmaceuticalNumber → TextFieldWrapper?
Pharmaceutical Number
no setter
reasonForTreatment → TextFieldWrapper?
Reason For Treatment
no setter
relevantInfo → TextFieldWrapper?
Relevant Info
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
substances → List<DEMedicalPlanSubheadingMedicineSubstance>
A list of all children of type "Substance".
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.