Field class

Generic document field.

Constructors

Field({required FieldType type, required OcrResult? value, double confidenceWeight = 1.0, ImageRef? image, required List<Point<double>> polygonInRoot, FieldValidationStatus validationStatus = FieldValidationStatus.NONE, List<FieldParsedData>? parsedData})
Field.fromJson(Map<String, dynamic> json)
factory

Properties

confidenceWeight → double
Confidence weight.
final
hashCode → int
The hash code for this object.
no setterinherited
image → ImageRef?
Crop of the field.
final
parsedData → List<FieldParsedData>
Parsed data.
final
polygonInRoot → List<Point<double>>
Coordinates of the field in the root document coordinate system.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FieldType
The type of the field.
final
validationStatus → FieldValidationStatus
Field validation status. Applicable only to fields that support some kind of validation.
final
value → OcrResult?
Value of the field. Applicable only to text fields.
final

Methods

encodeImages() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited