IDCardPDF417 class

ID Card

Inheritance

Constructors

IDCardPDF417(GenericDocument document)

Properties

birthDate → TextFieldWrapper
Birth Date. The format is ISO8601 with delimiters
no setter
dateExpired → TextFieldWrapper
Date Expired. The format is ISO8601 with delimiters
no setter
dateIssued → TextFieldWrapper
Date Issued. The format is ISO8601 with delimiters
no setter
document → GenericDocument
finalinherited
documentCode → TextFieldWrapper
Document Code
no setter
firstName → TextFieldWrapper
First Name
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastName → TextFieldWrapper
Last Name
no setter
optional → TextFieldWrapper
Optional
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.