MedicalCertificate class

Medical Certificate

Inheritance

Constructors

MedicalCertificate(GenericDocument document)

Properties

accident → TextFieldWrapper?
Accident
no setter
assignedToAccidentInsuranceDoctor → TextFieldWrapper?
Assigned To Accident Insurance Doctor
no setter
birthDate → TextFieldWrapper?
Birth Date. The format is ISO8601 with delimiters
no setter
childNeedsCareFrom → TextFieldWrapper?
Child Needs Care From
no setter
childNeedsCareUntil → TextFieldWrapper?
Child Needs Care Until
no setter
diagnose → TextFieldWrapper?
Diagnose
no setter
diagnosedOn → TextFieldWrapper?
Diagnosed On. The format is ISO8601 with delimiters
no setter
doctorNumber → TextFieldWrapper?
Doctor Number
no setter
document → GenericDocument
finalinherited
documentDate → TextFieldWrapper?
Document Date. The format is ISO8601 with delimiters
no setter
firstName → TextFieldWrapper?
First Name
no setter
hashCode → int
The hash code for this object.
no setterinherited
healthInsuranceNumber → TextFieldWrapper?
Health Insurance Number
no setter
incapableOfWorkSince → TextFieldWrapper?
Incapable Of Work Since. The format is ISO8601 with delimiters
no setter
incapableOfWorkUntil → TextFieldWrapper?
Incapable Of Work Until. The format is ISO8601 with delimiters
no setter
initialCertificate → TextFieldWrapper?
Initial Certificate
no setter
insuredPersonNumber → TextFieldWrapper?
Insured Person Number
no setter
lastName → TextFieldWrapper?
Last Name
no setter
placeOfOperationNumber → TextFieldWrapper?
Place Of Operation Number
no setter
renewedCertificate → TextFieldWrapper?
Renewed Certificate
no setter
requiredDocumentType → String
no setteroverride
requiresCare → TextFieldWrapper?
Requires Care
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TextFieldWrapper?
Status
no setter
workAccident → TextFieldWrapper?
Work Accident
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.