PathImageLoadOptions class

Options for loading image from path.

Constructors

PathImageLoadOptions({Rectangle<int>? roi, PathLoadMode loadMode = PathLoadMode.EAGER, EncryptionMode encryptionMode = EncryptionMode.IF_AVAILABLE})
PathImageLoadOptions.fromJson(Map<String, dynamic> json)
factory

Properties

encryptionMode ↔ EncryptionMode
Encryption mode.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loadMode ↔ PathLoadMode
Load mode.
getter/setter pair
roi ↔ Rectangle<int>
Region of interest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited