StructuredAppendInfo class

The structured append mode can be used to split a message across multiple barcodes.

Constructors

StructuredAppendInfo({required int count, required int index, required String id})
StructuredAppendInfo.fromJson(Map<String, dynamic> json)
factory

Properties

count → int
The number of barcodes in the structured append set.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the structured append set.
final
index → int
The index of the barcode in the structured append set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited