ToJsonConfiguration class

Configuration used to serialize an object to json.

Constructors

ToJsonConfiguration({bool serializeImages = true})
ToJsonConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serializeImages → bool
Serialize images in the object to json. If false, then fields that contain images are not serialized.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited