VCard class

VCard

Inheritance

Constructors

VCard(GenericDocument document)

Properties

agents → List<VCardAgent>
A list of all children of type "Agent".
no setter
anniversary → VCardAnniversary?
The child document of type "Anniversary".
no setter
birthday → VCardBirthday?
The child document of type "Birthday".
no setter
busyTimeURLS → List<VCardBusyTimeURL>
A list of all children of type "BusyTimeURL".
no setter
calendarURIForRequestss → List<VCardCalendarURIForRequests>
A list of all children of type "CalendarURIForRequests".
no setter
calendarURwe → List<VCardCalendarURI>
A list of all children of type "CalendarURI".
no setter
categorieses → List<VCardCategories>
A list of all children of type "Categories".
no setter
classification → VCardClassification?
The child document of type "Classification".
no setter
clientPIDMaps → List<VCardClientPIDMap>
A list of all children of type "ClientPIDMap".
no setter
customs → List<VCardCustom>
A list of all children of type "Custom".
no setter
deliveryAddresses → List<VCardDeliveryAddress>
A list of all children of type "DeliveryAddress".
no setter
document → GenericDocument
finalinherited
emails → List<VCardEmail>
A list of all children of type "Email".
no setter
formattedName → VCardFormattedName?
The child document of type "FormattedName".
no setter
gender → VCardGender?
The child document of type "Gender".
no setter
geoLocations → List<VCardGeoLocation>
A list of all children of type "GeoLocation".
no setter
hashCode → int
The hash code for this object.
no setterinherited
impps → List<VCardIMPP>
A list of all children of type "IMPP".
no setter
kind → VCardKind?
The child document of type "Kind".
no setter
labels → List<VCardLabel>
A list of all children of type "Label".
no setter
languageses → List<VCardLanguages>
A list of all children of type "Languages".
no setter
logos → List<VCardLogo>
A list of all children of type "Logo".
no setter
members → List<VCardMember>
A list of all children of type "Member".
no setter
name → VCardName?
The child document of type "Name".
no setter
nicknames → List<VCardNickname>
A list of all children of type "Nickname".
no setter
notes → List<VCardNote>
A list of all children of type "Note".
no setter
organisations → List<VCardOrganisation>
A list of all children of type "Organisation".
no setter
photos → List<VCardPhoto>
A list of all children of type "Photo".
no setter
productId → VCardProductId?
The child document of type "ProductId".
no setter
publicKeys → List<VCardPublicKey>
A list of all children of type "PublicKey".
no setter
relateds → List<VCardRelated>
A list of all children of type "Related".
no setter
requiredDocumentType → String
no setteroverride
revision → VCardRevision?
The child document of type "Revision".
no setter
roles → List<VCardRole>
A list of all children of type "Role".
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortString → VCardSortString?
The child document of type "SortString".
no setter
sounds → List<VCardSound>
A list of all children of type "Sound".
no setter
sources → List<VCardSource>
A list of all children of type "Source".
no setter
telephoneNumbers → List<VCardTelephoneNumber>
A list of all children of type "TelephoneNumber".
no setter
timeZones → List<VCardTimeZone>
A list of all children of type "TimeZone".
no setter
titles → List<VCardTitle>
A list of all children of type "Title".
no setter
uid → VCardUID?
The child document of type "UID".
no setter
urls → List<VCardURL>
A list of all children of type "URL".
no setter
version → VCardVersion
The child document of type "Version".
no setter
xmls → List<VCardXML>
A list of all children of type "XML".
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.