BarcodeScannerUiResult class

Results of the barcode scan.

Constructors

BarcodeScannerUiResult({double selectedZoomFactor = 1.0, List<BarcodeScannerUiItem>? items})
BarcodeScannerUiResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<BarcodeScannerUiItem>
Scanned barcode items.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedZoomFactor → double
Selected zoom factor for the camera.
final

Methods

encodeImages() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited