ExpectedBarcode class

Configuration of the barcode to find and scan.

Constructors

ExpectedBarcode({required String barcodeValue, String? title = null, String? image = null, int count = 1})
ExpectedBarcode.fromJson(Map<String, dynamic> json)
factory

Properties

barcodeValue ↔ String
Value of the barcode to find. If not set, any barcode value will be accepted.
getter/setter pair
count ↔ int
Number of barcodes with given symbology/value required to scan.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
Image of the barcode to find.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of the barcode to find.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited