FindAndPickBadgeConfiguration class

Configuration of the round badge on find and pick ar layer.

Constructors

FindAndPickBadgeConfiguration({BadgeStyle? partiallyScanned, BadgeStyle? rejected, BadgeStyle? completed})
FindAndPickBadgeConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

completed ↔ BadgeStyle
Appearance of the badge when a barcode is completed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partiallyScanned ↔ BadgeStyle
Appearance of the badge when a barcode is partially scanned.
getter/setter pair
rejected ↔ BadgeStyle
Appearance of the badge when a barcode is rejected.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited