SwipeToDelete class

Configuration of the swipe-to-delete button.

Constructors

SwipeToDelete({bool enabled = true, ScanbotColor? backgroundColor, ScanbotColor? iconColor})
SwipeToDelete.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor ↔ ScanbotColor
Color of the swipe-to-delete button.
getter/setter pair
enabled ↔ bool
Whether swipe to delete is enabled or not.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconColor ↔ ScanbotColor
Color of the icon on the swipe-to-delete button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited