ActionBarConfiguration class

Configuration of the buttons available in the action bar.

Constructors

ActionBarConfiguration({RoundButton? flashButton, RoundButton? zoomButton, RoundButton? flipCameraButton})
ActionBarConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

flashButton ↔ RoundButton
Configuration of the 'flash' button.
getter/setter pair
flipCameraButton ↔ RoundButton
Configuration of the 'flip camera' button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomButton ↔ RoundButton
Configuration of the 'zoom' button.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited