EdgeInsets class

Represents the insets of a rectangle.

Constructors

EdgeInsets({double top = 0.0, double left = 0.0, double bottom = 0.0, double right = 0.0})
EdgeInsets.fromJson(Map<String, dynamic> json)
factory

Properties

bottom ↔ double
The bottom inset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ double
The left inset.
getter/setter pair
The right inset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ double
The top inset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited