StyledText class

Configuration of the text field appearance.

Constructors

StyledText({bool visible = true, String text = "", ScanbotColor? color, bool useShadow = false})
StyledText.fromJson(Map<String, dynamic> json)
factory

Properties

color ↔ ScanbotColor
The text color.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
The value of the text field.
getter/setter pair
useShadow ↔ bool
Determines whether to enable drop shadows for the text.
getter/setter pair
visible ↔ bool
Determines whether the text field is visible or not.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited