Timeouts class

Configuration of timeouts.

Constructors

Timeouts({int autoCancelTimeout = 0, int initialScanDelay = 0})
Timeouts.fromJson(Map<String, dynamic> json)
factory

Properties

autoCancelTimeout ↔ int
Sets the length of time, in milliseconds, when the scanner should auto close. Default is 0 (disabled).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialScanDelay ↔ int
Sets the length of time, in milliseconds, that the first scan will be delayed by. Default is 0 (disabled).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited