AAMVATitleData class

Title Data. File type "TD".

Inheritance

Constructors

AAMVATitleData(GenericDocument document)

Properties

addressCity → TextFieldWrapper?
Data element ID "NAT". City portion of the owner’s address.
no setter
addressJurisdictionCode → TextFieldWrapper?
Data element ID "NAU". Jurisdiction portion of the owner’s address.
no setter
addressStreet → TextFieldWrapper?
Data element ID "NAR". Street portion of the owner’s address.
no setter
addressZipCode → TextFieldWrapper?
Data element ID "NAV". The ZIP code or Postal code portion of the owner’s address.
no setter
businessName → TextFieldWrapper?
Data element ID "BBC". The name of business that owns the vehicle.
no setter
document → GenericDocument
finalinherited
familyName → TextFieldWrapper?
Data element ID "NAA". Family name (commonly called surname or last name) of the owner of the vehicle.
no setter
firstLienHolderId → TextFieldWrapper?
Data element ID "LAF". A code that uniquely identifies the first holder of a lien.
no setter
firstLienHolderName → TextFieldWrapper?
Data element ID "LAA". Name of the first lien holder of the vehicle.
no setter
givenName → TextFieldWrapper?
Data element ID "NAE". Given name or names (includes all of what are commonly referred to as first and middle names) of the owner of the vehicle.
no setter
hashCode → int
The hash code for this object.
no setterinherited
newUsedIndicator → TextFieldWrapper?
Data element ID "TAW". This code represents whether the vehicle/vessel is new or used. Note: jurisdictions’ definitions of these classifications may vary a little due to state regulations on demo vehicles, slates between dealers, application of state taxes, etc. N = New, U = Used.
no setter
odometerDate → TextFieldWrapper?
Data element ID "TAH". The date the odometer reading was recorded by the jurisdiction.
no setter
odometerDisclosure → TextFieldWrapper?
Data element ID "TAG". This is the federal odometer mileage disclosure. The mandatory information is: (1) Actual vehicle mileage; (2) Mileage exceeds mechanical limitations; (3) Not actual mileage; (4) Mileage disclosure not required.
no setter
odometerReadingKilometers → TextFieldWrapper?
Data element ID "TAI". This is the odometer reading registered with the DMV either at the time of titling or registration renewal in kilometers.
no setter
odometerReadingMileage → TextFieldWrapper?
Data element ID "TAF". This is the odometer reading registered with the DMV either at the time of titling or registration renewal.
no setter
previousTitleNumber → TextFieldWrapper?
Data element ID "TAZ". The title number assigned to the vehicle by the previous titling jurisdiction.
no setter
previousTitlingJurisdiction → TextFieldWrapper?
Data element ID "TPJ". The code for the jurisdiction (U.S., Canadian, or Mexican) that titled the vehicle immediately prior to the current titling jurisdiction.
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleBrand → TextFieldWrapper?
Data element ID "TAY". Code providing information about the brand applied to the title.
no setter
titleIssueDate → TextFieldWrapper?
Data element ID "TAV". The date the jurisdiction’s titling authority issued a title to the owner of the vehicle. The format is CCYYMMDD.
no setter
titleNumber → TextFieldWrapper?
Data element ID "TAA". The date the jurisdiction’s titling authority issued a title to the owner of the vehicle. The format is CCYYMMDD.
no setter
titlingJurisdiction → TextFieldWrapper?
Data element ID "TAC". A unique set of alphanumeric characters assigned by the titling jurisdiction to the certificate of title of a vehicle.
no setter
vehicleBodyStyle → TextFieldWrapper?
Data element ID "VAO". The general configuration or shape of a vehicle distinguished by characteristics such as number of doors, seats, windows, roofline, and type of top. The vehicle body type is 2-character alphanumeric.
no setter
vehicleColor → TextFieldWrapper?
Data element ID "VBD". Where the vehicle/vessel is one color, this is the appropriate code describing that color. When the vehicle is two colors, this is the code for the top-most or front-most color.
no setter
vehicleIdentificationNumber → TextFieldWrapper?
Data element ID "VAD". A unique combination of alphanumeric characters that identifies a specific vehicle or component. The VIN is affixed to the vehicle in specific locations and formulated by the manufacturer. State agencies under some controlled instances may assign a VIN to a vehicle.
no setter
vehicleMake → TextFieldWrapper?
Data element ID "VAK". The distinctive (coded) name applied to a group of vehicles by a manufacturer.
no setter
vehicleModel → TextFieldWrapper?
Data element ID "VAM". A code denoting a family of vehicles (within a make), which has a degree of similarity in construction, such as body, chassis, etc. The field does not necessarily contain a standard code; it may contain a value provided by the originator of the field.
no setter
vehicleModelYear → TextFieldWrapper?
Data element ID "VAL". The year that is assigned to a vehicle by the manufacturer. The format is CCYY.
no setter
vehiclePurchaseDate → TextFieldWrapper?
Data element ID "TAU". The date a vehicle was purchased by the current owner. The format is ISO8601 with delimiters.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.