BadgeStyle class

Configuration of the badge.

Constructors

BadgeStyle({bool visible = true, BackgroundStyle? background, ScanbotColor? foregroundColor})
BadgeStyle.fromJson(Map<String, dynamic> json)
factory

Properties

background ↔ BackgroundStyle
Configuration of the background appearance for the badge.
getter/setter pair
foregroundColor ↔ ScanbotColor
The color of the badge's foreground (icon, text).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visible ↔ bool
Determines whether the badge is visible or not.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited