method property
The method how to display barcodes from previous frames.
Default is INTERPOLATE_BY_CAMERA.
Implementation
BarcodeAccumulationMethod method;
The method how to display barcodes from previous frames.
Default is INTERPOLATE_BY_CAMERA.
BarcodeAccumulationMethod method;