BarcodeAccumulationMethod enum

The method how to display barcodes from previous frames.

Inheritance
Available extensions

Values

LAST_VISIBLE → const BarcodeAccumulationMethod

The quad of a barcode is simply given as the last quad when it was detected.

INTERPOLATE_BY_CAMERA → const BarcodeAccumulationMethod

The quad of barcode is interpolated by the camera movement. This option is recommended when the camera is moving, but the scanned object is not.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BarcodeAccumulationMethod>
A constant List of the values in this enum, in order of their declaration.