BarcodeDocumentParserResult class

The result of barcode document parsing.

Constructors

BarcodeDocumentParserResult({required bool success, required GenericDocument? parsedDocument})
BarcodeDocumentParserResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parsedDocument → GenericDocument?
In case of success, the parsed document.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
True if any document was parsed.
final

Methods

encodeImages() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited