useCode39CheckDigit property
If true, return CODE_39 barcodes only if they have a valid check digit.
Default is false.
Implementation
bool useCode39CheckDigit;
If true, return CODE_39 barcodes only if they have a valid check digit.
Default is false.
bool useCode39CheckDigit;