twoDDecoderMode property

TwoDDecodingMode twoDDecoderMode
getter/setter pair

Allows to select the balance between decoding speed and recall in harsh conditions such as barcodes on curved surfaces or partial occlusions.

Default is HIGH_EFFORT

Implementation

TwoDDecodingMode twoDDecoderMode;