strictMode property
If true, the barcode scanner will only return barcodes that pass the strict validation checks according to standards to avoid false positives.
Default is true.
Implementation
bool strictMode;
If true, the barcode scanner will only return barcodes that pass the strict validation checks according to standards to avoid false positives.
Default is true.
bool strictMode;