oneDConfirmationMode property
Allows to select the balance between result accuracy (precision) and missed barcodes (recall) for linear barcodes.
Default is THOROUGH.
Implementation
OneDConfirmationMode oneDConfirmationMode;
Allows to select the balance between result accuracy (precision) and missed barcodes (recall) for linear barcodes.
Default is THOROUGH.
OneDConfirmationMode oneDConfirmationMode;