allowNarrowBarsOnly property
If true, a result consisting of only narrow bars is accepted as valid. The specification does not recommend such barcodes. Default is false.
Default is false.
Implementation
bool allowNarrowBarsOnly;
If true, a result consisting of only narrow bars is accepted as valid. The specification does not recommend such barcodes. Default is false.
Default is false.
bool allowNarrowBarsOnly;