BarcodeFormatUpcEanConfiguration class

UPC/EAN barcode configuration. Add to scanner configuration to scan EAN-8, EAN-13, UPC-E and UPC-A barcodes.

Inheritance

Constructors

BarcodeFormatUpcEanConfiguration({String regexFilter = "", double minimumSizeScore = 0.0, bool addAdditionalQuietZone = false, int minimum1DQuietZoneSize = 6, int minimumNumberOfRequiredFramesWithEqualRecognitionResult = 1, OneDConfirmationMode oneDConfirmationMode = OneDConfirmationMode.THOROUGH, bool stripCheckDigits = false, BarcodeDefectProfile barcodeDefectProfile = BarcodeDefectProfile.GENERIC_AND_THERMAL, ConfigState blurryOneDScanner = ConfigState.ENABLE, ConfigState damagedBarcodeReconstruction = ConfigState.ENABLE, bool ean8 = true, bool ean13 = true, bool upca = true, bool upce = true, UpcEanExtensionBehavior extensions = UpcEanExtensionBehavior.ALLOW_ANY, int minimumNumberOfRequiredFramesWithEqualRecognitionResultExtensionless = 1, bool convertUpceToUpca = false})
BarcodeFormatUpcEanConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

addAdditionalQuietZone ↔ bool
If true, we process the barcode scanning with an artificial quiet zone that we add to the input image. This flag should be used to scan sharp crops of a barcode in single-shot mode.
getter/setter pairinherited
barcodeDefectProfile ↔ BarcodeDefectProfile
Specifies which kind of barcode defects are tried to fix.
getter/setter pair
blurryOneDScanner ↔ ConfigState
If ENABLE, the scanner will try extra-hard to scan linear barcodes that are heavily blurred or otherwise damaged.
getter/setter pair
convertUpceToUpca ↔ bool
UPC-E is a 6-digit code, that has its equivalent in UPC-A 12-digit code with number system 0 or 1. If true, convert this 6-digit code into the corresponding 12-digit code. If false, return the UPC-E code as is.
getter/setter pair
damagedBarcodeReconstruction ↔ ConfigState
If ENABLE, the scanner will try extra-hard to scan linear barcodes that are damaged in a way that every single scanline is corrupted, e.g. due to scratches, ink smudges, glare, or other damage or obstruction. Only affects the following barcode formats: Code39, Code128, Ean8, Ean13, and UpcA. Not used in low power or legacy mode.
getter/setter pair
ean13 ↔ bool
If true, scan and return valid EAN-13 barcodes.
getter/setter pair
ean8 ↔ bool
If true, scan and return valid EAN-8 barcodes.
getter/setter pair
extensions ↔ UpcEanExtensionBehavior
Behavior when scanning UPC/EAN barcodes with EAN-2 or EAN-5 extensions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minimum1DQuietZoneSize ↔ int
Minimum quiet zone size on the left and right sides of a 1D barcode, measured in number of modules. The quiet zone is only for 1D barcodes with weak start/stop patterns, i.e. Iata2Of5, Industrial2Of5, Code25, Itf, Codabar, MsiPlessey and Code11.
getter/setter pairinherited
minimumNumberOfRequiredFramesWithEqualRecognitionResult ↔ int
Minimum number of frames on which a linear (1D) barcode has to be detected to be considered valid (live scanning only). Linear barcodes are more prone to false positives. Increasing the number of frames on which a barcode has to decode to the same content reduces the probability of a false positive.
getter/setter pairinherited
minimumNumberOfRequiredFramesWithEqualRecognitionResultExtensionless ↔ int
In case that EAN/UPC barcodes both with and without extensions are allowed, we require this number of frames on which the standalone EAN or UPC (i.e. without extension) has to be detected to be considered as valid (live scanning only). EAN/UPC barcodes with extensions are more prone to slicing (incomplete decoding). Increasing the number of frames on which a barcode has to decode to the same content reduces the probability that an extension is accidentally missed.
getter/setter pair
minimumSizeScore ↔ double
Minimum acceptable value of a result BarcodeItem's sizeScore (between 0 and 1). Barcodes with a sizeScore less than this value will not be scanned. When set to 0, barcodes are returned no matter what their size is.
getter/setter pairinherited
oneDConfirmationMode ↔ OneDConfirmationMode
Allows to select the balance between result accuracy (precision) and missed barcodes (recall) for linear barcodes.
getter/setter pairinherited
regexFilter ↔ String
Regular expression filter for barcode text. If the barcode text does not match the regular expression, it will not be scanned. The default is an empty string (setting is turned off).
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stripCheckDigits ↔ bool
If true, the check digits are stripped from the result.
getter/setter pair
upca ↔ bool
If true, scan and return valid UPC-A barcodes. If false, but ean13 is true, then UPC-A barcodes will be returned as EAN-13 barcodes.
getter/setter pair
upce ↔ bool
If true, scan and return valid UPC-E barcodes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited