BarcodeItemConfiguration class

Configuration of the barcode info box displayed in the camera preview.

Constructors

BarcodeItemConfiguration({bool imageVisible = true, StyledText? titleSelected, StyledText? subtitleSelected, StyledText? titleDeselected, StyledText? subtitleDeselected, PolygonStyle? backgroundSelected, PolygonStyle? backgroundDeselected})
BarcodeItemConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundDeselected ↔ PolygonStyle
Appearance of the barcode info box's background when a barcode is yet to be selected.
getter/setter pair
backgroundSelected ↔ PolygonStyle
Appearance of the barcode info box's background when a barcode has been selected.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageVisible ↔ bool
Control the visibility of the barcode image in the info box.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleDeselected ↔ StyledText
Configuration of the text displaying a barcode's symbology in the info box when the barcode is yet to be selected.
getter/setter pair
subtitleSelected ↔ StyledText
Configuration of the text displaying a barcode's symbology in the info box when the barcode has been selected.
getter/setter pair
titleDeselected ↔ StyledText
Configuration of the text displaying a barcode's value in the info box when the barcode is yet to be selected.
getter/setter pair
titleSelected ↔ StyledText
Configuration of the text displaying a barcode's value in the info box when the barcode has been selected.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited