BarcodeItemErrorState class

Configuration of the mapper's error dialog.

Constructors

BarcodeItemErrorState({StyledText? title, StyledText? subtitle, ButtonConfiguration? retryButton, ButtonConfiguration? cancelButton})
BarcodeItemErrorState.fromJson(Map<String, dynamic> json)
factory

Properties

cancelButton ↔ ButtonConfiguration
Configuration of the cancel button.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
retryButton ↔ ButtonConfiguration
Configuration of the retry button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ StyledText
Error message.
getter/setter pair
title ↔ StyledText
Title displayed above the error message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited