onlyAcceptDocuments property
If true and extractedDocumentFormats is not empty, then barcodes that don't decode to one of the extracted document formats will be ignored.
Default is false.
Implementation
bool onlyAcceptDocuments;
If true and extractedDocumentFormats is not empty, then barcodes that don't decode to one of the extracted document formats will be ignored.
Default is false.
bool onlyAcceptDocuments;