returnBarcodeImage property
If true, the barcode image will be returned in the BarcodeItem.
Default is false.
Implementation
bool returnBarcodeImage;
If true, the barcode image will be returned in the BarcodeItem.
Default is false.
bool returnBarcodeImage;