BarcodeScannerEngineMode enum

The engine mode for barcode scanning.

Inheritance
Available extensions

Values

LEGACY → const BarcodeScannerEngineMode

Legacy mode. Very fast, significantly less accurate. Doesn't support all barcode types.

NEXT_GEN_LOW_POWER → const BarcodeScannerEngineMode

A faster version of the main engine mode, for use with low-power devices.

NEXT_GEN → const BarcodeScannerEngineMode

Main engine mode for high-power devices. Supports all barcodes types.

NEXT_GEN_LOW_POWER_FAR_DISTANCE → const BarcodeScannerEngineMode

Similar to NEXT_GEN_LOW_POWER, but optimized for scanning from far distances.

NEXT_GEN_FAR_DISTANCE → const BarcodeScannerEngineMode

Similar to NEXT_GEN, but optimized for scanning from far distances. In single‑shot mode, performance can be slow and may require significant memory depending on input resolution.

NEXT_GEN_MAX_DISTANCE → const BarcodeScannerEngineMode

Similar to NEXT_GEN_FAR_DISTANCE, but optimized for scanning from far distances on very high power devices. In single‑shot mode, performance can be very slow and may require significant memory depending on input resolution.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BarcodeScannerEngineMode>
A constant List of the values in this enum, in order of their declaration.