keepScreenOn property
If enabled, the screen will not turn off while the barcode scanner is active.
Default is true.
Implementation
bool keepScreenOn;
If enabled, the screen will not turn off while the barcode scanner is active.
Default is true.
bool keepScreenOn;