BarcodeSelectionConfiguration class

Configuration for how to select barcode results.

Constructors

BarcodeSelectionConfiguration({BarcodeSelectionMethod selectionMethod = BarcodeSelectionMethod.ALL, double centerCoordX = 0.5, double centerCoordY = 0.5, double centerDistanceTolerance = 0.0})
BarcodeSelectionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

centerCoordX ↔ double
The normalized x‑coordinate of the image center, expressed in the range [0,1]. Only used when selectionMethod is CENTER or CENTER_CLOSEST. The default is the center of the image, but can be set to other coordinates for use cases where the center of the frame may not be the point of interest.
getter/setter pair
centerCoordY ↔ double
The normalized y‑coordinate of the image center, expressed in the range [0,1]. Only used when selectionMethod is CENTER or CENTER_CLOSEST. The default is the center of the image, but can be set to other coordinates for use cases where the center of the frame may not be the point of interest.
getter/setter pair
centerDistanceTolerance ↔ double
The maximum allowed distance from centerCoord at which a barcode may still be selected when selectionMethod is CENTER. If multiple barcodes are within the tolerance, the closest one will be selected. The value is expressed in terms of the image size, where 1.0 means the maximum distance which is equal to the diagonal of the image. The default value is 0, which means that barcodes must touch the center of the frame to be selected. Increasing this value can help with selecting barcodes that are close to the center but not touching it.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionMethod ↔ BarcodeSelectionMethod
The method used to select barcodes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited