BarcodeSelectionMethod enum

The method used to select barcodes.

Inheritance
Available extensions

Values

ALL → const BarcodeSelectionMethod

All detected barcodes are returned.

CENTER → const BarcodeSelectionMethod

Only the single barcode touching the center of the frame is returned. Selecting this option disables frame accumulation.

CENTER_CLOSEST → const BarcodeSelectionMethod

Only the barcode closest to the center of the frame is returned. Selecting this option disables frame accumulation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BarcodeSelectionMethod>
A constant List of the values in this enum, in order of their declaration.