BasicImageLoadOptions class

Basic options for loading image.

Constructors

BasicImageLoadOptions({Rectangle<int>? cropRect, CanvasColor canvasColor = CanvasColor.WHITE})
BasicImageLoadOptions.fromJson(Map<String, dynamic> json)
factory

Properties

canvasColor ↔ CanvasColor
CanvasColor color to use when converting images with alpha channel to images without alpha channel.
getter/setter pair
cropRect ↔ Rectangle<int>
If the rect is not empty, the image will be cropped to this rect before processing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited