BritishColumbiaDriverLicense class

British Columbia (Canada) driver license

Inheritance

Properties

address TextFieldWrapper
Address
no setter
birthDate TextFieldWrapper
Birth date in CCYYMMDD format
no setter
cardExpiry TextFieldWrapper
Card expiry in YYMM format
no setter
cardNumber TextFieldWrapper
Card Number
no setter
city TextFieldWrapper
City
no setter
document GenericDocument
finalinherited
errorControlCode TextFieldWrapper
Error control code
no setter
eyeColor TextFieldWrapper
Eye color
no setter
givenNames TextFieldWrapper
Given names
no setter
hairColor TextFieldWrapper
Hair color
no setter
hashCode int
The hash code for this object.
no setterinherited
height TextFieldWrapper
Height
no setter
lastName TextFieldWrapper
Last name
no setter
personalHealthNumber TextFieldWrapper
Personal health number
no setter
postalCode TextFieldWrapper
Postal code
no setter
province TextFieldWrapper
Province
no setter
provinceCode TextFieldWrapper
Province code
no setter
requiredDocumentType String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityFunction TextFieldWrapper
Security function
no setter
securityVersion TextFieldWrapper
Security Version
no setter
sex TextFieldWrapper
Sex
no setter
version TextFieldWrapper
Version
no setter
weight TextFieldWrapper
Weight
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.