cameraPreviewAspectRatio property

CameraPreviewAspectRatio? cameraPreviewAspectRatio
getter/setter pair

Tries to select the camera preview aspect ratio that best matches the given aspect ratio. If no exact match is found, it selects the closest one available. Android only.

Implementation

CameraPreviewAspectRatio? cameraPreviewAspectRatio;