hardwareButtonsEnabled property
When enabled it allows zooming using camera control button (iPhone 16 series). iOS only.
Default is true.
Implementation
bool hardwareButtonsEnabled;
When enabled it allows zooming using camera control button (iPhone 16 series). iOS only.
Default is true.
bool hardwareButtonsEnabled;