minFocusDistanceLock property
Determines whether to lock the focus at the minimum possible distance (device-specific).
Default is false.
Implementation
bool minFocusDistanceLock;
Determines whether to lock the focus at the minimum possible distance (device-specific).
Default is false.
bool minFocusDistanceLock;