statusBarMode property
Determines the visual mode for displaying the contents of the status bar.
Default is DARK.
Implementation
StatusBarMode statusBarMode;
Determines the visual mode for displaying the contents of the status bar.
Default is DARK.
StatusBarMode statusBarMode;