CameraPreviewAspectRatio enum

Tries to select the camera preview aspect ratio that best matches the given aspect ratio. If no exact match is found, it selects the closest one available. Android only.

Inheritance
Available extensions

Values

RATIO_4_3 → const CameraPreviewAspectRatio

Standard preview aspect ratio used by most of the devices.

RATIO_16_9 → const CameraPreviewAspectRatio

Widescreen preview aspect ratio used by some devices.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CameraPreviewAspectRatio>
A constant List of the values in this enum, in order of their declaration.