DEMedicalPlan class

Medical Plan

Inheritance

Constructors

DEMedicalPlan(GenericDocument document)

Properties

currentPage → TextFieldWrapper
Current Page
no setter
doctor → DEMedicalPlanDoctor
The child document of type "Doctor".
no setter
document → GenericDocument
finalinherited
documentVersionNumber → TextFieldWrapper
Document Version Number
no setter
guid → TextFieldWrapper
GUID
no setter
hashCode → int
The hash code for this object.
no setterinherited
languageCountryCode → TextFieldWrapper
Language Country Code
no setter
patchVersionNumber → TextFieldWrapper
Patch Version Number
no setter
patient → DEMedicalPlanPatient
The child document of type "Patient".
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subheadings → List<DEMedicalPlanSubheading>
A list of all children of type "Subheading".
no setter
totalNumberOfPages → TextFieldWrapper
Total Number Of Pages
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.