DeviceDeregistrationError class

Description of error that occurred during device deregistration.

Constructors

DeviceDeregistrationError({required int deviceId, required String errorMessage})
DeviceDeregistrationError.fromJson(Map<String, dynamic> json)
factory

Properties

deviceId → int
Sequential number of the device registration. Starts with 0. Each time a call to initializeLicense with a new license is made, the device ID.
final
errorMessage → String
Error message describing the error.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited