ExtractImagesFromPdfParams class

Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true, createFactory: false)

Constructors

ExtractImagesFromPdfParams({required String pdfFilePath, int? scaling, EncodingFormat? compressFormat, int? quality})

Properties

compressFormat ↔ EncodingFormat?
Compress format used for extracted images. Android only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pdfFilePath ↔ String
The location of the PDF file
getter/setter pair
quality ↔ int?
The quality that each extracted image should have. This tweaks the compression, affecting the final image file size. (100: maximum quality, 0: minimum quality)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaling ↔ int?
Integer scaling factor applied to the PDF media box frame while extracting. Affects the output image quality. In most cases the recommended value is 2 or higher.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited