FieldType class

Generic Document Type.

Constructors

FieldType({required String name, required String fullName, required String normalizedName, required CommonFieldType? commonType, int? listIndex = null})
FieldType.fromJson(Map<String, dynamic> json)
factory

Properties

commonType → CommonFieldType?
Commonly occurring fields that have the same semantic meaning in different document types will often have a set common type.
final
fullName → String
Unique global field type name prefixed with the document types of all containing documents.
final
hashCode → int
The hash code for this object.
no setterinherited
listIndex → int?
A document can contain multiple fields of the same name, the property serves for storing natural order of such fields, null if multiple entries aren't allowed for this field.
final
name → String
Local field type name scoped to the containing document type.
final
normalizedName → String
Normalized global field type name. Fields in document types derived from the same base document type in the schema will have the same normalized name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited