allowPartialScan property
If the user is allowed to finish the scanning process without scanning all the expected barcodes.
Default is false.
Implementation
bool allowPartialScan;
If the user is allowed to finish the scanning process without scanning all the expected barcodes.
Default is false.
bool allowPartialScan;