onFinderRectChange property
Triggers when the finder area is changed, it's helpful to align some content on top of the finder
Implementation
final OnFinderRectChange? onFinderRectChange;
Triggers when the finder area is changed, it's helpful to align some content on top of the finder
final OnFinderRectChange? onFinderRectChange;