FlutterLicense class

Inheritance

Constructors

FlutterLicense(Iterable<String> packages, Iterable<LicenseParagraph> paragraphs)

Properties

hashCode → int
The hash code for this object.
no setterinherited
packages ↔ Iterable<String>
The names of the packages that this license entry applies to.
getter/setter pairoverride-getter
paragraphs ↔ Iterable<LicenseParagraph>
The paragraphs of the license, each as a LicenseParagraph consisting of a string and some formatting information.
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited