paragraphs property
The paragraphs of the license, each as a LicenseParagraph consisting of
a string and some formatting information.
Paragraphs can include newline characters, but this is discouraged as it results in ugliness.
Implementation
@override
Iterable<LicenseParagraph> paragraphs = [];