GS1 class

GS1

Inheritance

Constructors

GS1(GenericDocument document)

Properties

document → GenericDocument
finalinherited
elements → List<GS1Element>
A list of all children of type "Element".
no setter
hashCode → int
The hash code for this object.
no setterinherited
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.