GS1Element class

GS1 Element

Inheritance

Constructors

GS1Element(GenericDocument document)

Properties

applicationIdentifier → TextFieldWrapper
Application Identifier
no setter
dataTitle → TextFieldWrapper
Data Title
no setter
document → GenericDocument
finalinherited
elementDescription → TextFieldWrapper
Description
no setter
hashCode → int
The hash code for this object.
no setterinherited
rawValue → TextFieldWrapper
Raw Value
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationErrors → List<GS1ElementValidationError>
A list of all children of type "ValidationError".
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.