GenericDocument class

Generic document.

Available extensions

Constructors

GenericDocument({required GenericDocumentType type, required List<Field> fields, required List<GenericDocument> children, required List<Point<double>> quad, required List<Point<double>> quadInRoot, ImageRef? crop, double confidence = 0.0, double confidenceWeight = 0.0})
GenericDocument.fromJson(Map<String, dynamic> json)
factory

Properties

children → List<GenericDocument>
List of document sub-documents.
final
confidence → double
The average confidence in the accuracy of the document recognition result.
final
confidenceWeight → double
The weight of the confidence. Can be used to calculate the weighted average confidence of two documents.
final
crop → ImageRef?
Image crop of the document.
final
fields → List<Field>
List of document fields.
final
hashCode → int
The hash code for this object.
no setterinherited
quad → List<Point<double>>
Coordinates of the document in the parent document coordinate system.
final
quadInRoot → List<Point<double>>
Coordinates of the document in the root document coordinate system.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GenericDocumentType
Document type.
final

Methods

childByDocumentType(String name) → GenericDocument?

Available on GenericDocument, provided by the GenericDocumentExtension extension

Returns a sub-document given its document type name. Returns null if not found.
childrenByDocumentType(String name) → List<GenericDocument>

Available on GenericDocument, provided by the GenericDocumentExtension extension

Returns all children of generic document given its document type name. Returns null if not found.
encodeImages() → void
fieldByTypeName(String name) → Field?

Available on GenericDocument, provided by the GenericDocumentExtension extension

Returns a field given its local or common type name. Returns null if not found.
fieldsByTypeName(String name) → List<Field>

Available on GenericDocument, provided by the GenericDocumentExtension extension

Returns all fields given a local or common field type name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited