GenericDocumentType class

Generic Document Type.

Constructors

GenericDocumentType({required String name, required String fullName, required String normalizedName, int? listIndex = null})
GenericDocumentType.fromJson(Map<String, dynamic> json)
factory

Properties

fullName → String
Unique global document type name prefixed with the document types of all containing documents.
final
hashCode → int
The hash code for this object.
no setterinherited
listIndex → int?
A document can contain multiple fields of the same name, the property serves for storing natural order of such fields, null if multiple entries aren't allowed for this field.
final
name → String
Local document type name.
final
normalizedName → String
Normalized global document type name. Common document types appearing as child documents in different places will often have the same normalized type name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited