HIBC class

HIBC

Inheritance

Constructors

HIBC(GenericDocument document)

Properties

dateOfManufacture → TextFieldWrapper?
Date of Manufacture
no setter
document → GenericDocument
finalinherited
expiryDateDay → TextFieldWrapper?
Expiry Date Day
no setter
expiryDateHour → TextFieldWrapper?
Expiry Date Hour
no setter
expiryDateJulianDay → TextFieldWrapper?
Expiry Date Julian Day
no setter
expiryDateMonth → TextFieldWrapper?
Expiry Date Month
no setter
expiryDateYear → TextFieldWrapper?
Expiry Date Year
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasPrimaryData → TextFieldWrapper
Information whether primary data is present.
no setter
hasSecondaryData → TextFieldWrapper
Information whether secondary data is present.
no setter
labelerIdentificationCode → TextFieldWrapper
Labeler Identification Code (LIC)
no setter
labelersProductOrCatalogNumber → TextFieldWrapper
Labelers Product or Catalog Number (PCN). Alphanumeric data.
no setter
linkCharacter → TextFieldWrapper?
Link character to link standalone primary and secondary barcodes together.
no setter
lotNumber → TextFieldWrapper?
Lot Number
no setter
quantity → TextFieldWrapper?
Quantity
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → TextFieldWrapper?
Serial Number
no setter
unitOfMeasureID → TextFieldWrapper
Unit of Measure ID, Numeric value only, 0 through 9, where 0 always represents a single unit. 1 to 8 are used to indicate different packaging levels above the unit of use. The value 9 is used for variable quantity containers when manual key entry or scan of a secondary will be used to collect specific quantity data. The labeler should ensure consistency in this field within their packaging process.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.