ImageProfile class

ImageRef profile part specific to image information.

Constructors

ImageProfile({int bitmapMemoryConsumption = 0, int hibernationMemoryConsumption = 0})
ImageProfile.fromJson(Map<String, dynamic> json)
factory

Properties

bitmapMemoryConsumption ↔ int
Memory consumption of a memory-backed bitmap. Zero, if the image is hibernating.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hibernationMemoryConsumption ↔ int
Memory consumption of the hibernation buffer. Zero, if the image is not hibernating, or is hibernated to a file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited