ImageRefProfile class

ImageRef profile which provides detailed information about stored object.

Constructors

ImageRefProfile({required RefCountedObjectProfile refInfo, required ImageProfile imageInfo, required ImageSource? imageSource})
ImageRefProfile.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageInfo ↔ ImageProfile
Image-specific information, e.g. memory consumption.
getter/setter pair
imageSource ↔ ImageSource?
Description of source from which the ImageRef was created. Non-null only if detailed profiling has been previously enabled by a call to enableDetailedProfiling.
getter/setter pair
refInfo ↔ RefCountedObjectProfile
Information about the strong and serialized references to the image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited