ImageSource class

Description of source from which the ImageRef was created.

Constructors

ImageSource({required ImageSourceType type, required String? filePath})
ImageSource.fromJson(Map<String, dynamic> json)
factory

Properties

filePath ↔ String?
File from which the ImageRef was created. Non-null only if the image ref was created from file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ImageSourceType
Source type from which the ImageRef was created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited