Insets class

Constructors

Insets({double? left, double? top, double? bottom, double? right})
const
Insets.all(double all)
factory
Insets.fromJson(Map<String, dynamic> json)
factory
Insets.horizontal(double inset)
factory
Insets.vertical(double inset)
factory

Properties

bottom → double?
Pixel for the finder window from the bottom.
final
hashCode → int
The hash code for this object.
no setterinherited
left → double?
Pixel for the finder window from the left.
final
Pixel for the finder window from the right.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double?
Pixel for the finder window from the top.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited