license property

String license
final

The currently active license. May be different from the license used to initialize the SDK if the online license check has completed and the server has sent an updated license.

Implementation

final String license;