LineSegmentFloat class

Represents a line segment in 2D space.

Constructors

LineSegmentFloat({required Point<double> start, required Point<double> end})
LineSegmentFloat.fromJson(Map<String, dynamic> json)
factory

Properties

end → Point<double>
End point of the segment.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Point<double>
Start point of the segment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited