PathImageLoadOptions class

Options for loading image from path.

Constructors

PathImageLoadOptions({Rectangle<int>? cropRect, ColorConversion colorConversion = ColorConversion.ANY_COLOR, CanvasColor canvasColor = CanvasColor.WHITE, PathLoadMode loadMode = PathLoadMode.EAGER, EncryptionMode encryptionMode = EncryptionMode.AUTO})
PathImageLoadOptions.fromJson(Map<String, dynamic> json)
factory

Properties

canvasColor ↔ CanvasColor
CanvasColor color to use when converting images with alpha channel to images without alpha channel.
getter/setter pair
colorConversion ↔ ColorConversion
Color conversion to apply during image loading.
getter/setter pair
cropRect ↔ Rectangle<int>
If the rect is not empty, the image will be cropped to this rect before processing.
getter/setter pair
encryptionMode ↔ EncryptionMode
Encryption mode.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loadMode ↔ PathLoadMode
Load mode.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited