PermanentViewFinderConfiguration class

Configuration of the scanning interface’s viewfinder, which is always visible to guide the user.

Inheritance

Constructors

PermanentViewFinderConfiguration({FinderStyle? style, ScanbotColor? overlayColor, AspectRatio? aspectRatio, ScanbotEdgeInsets? minimumInsets, double maxWidth = -1.0, double maxHeight = -1.0})
PermanentViewFinderConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

aspectRatio ↔ AspectRatio
The viewfinder's aspect ratio.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
maxHeight ↔ double
The maximum height of the viewfinder.
getter/setter pairinherited
maxWidth ↔ double
The maximum width of the viewfinder.
getter/setter pairinherited
minimumInsets ↔ ScanbotEdgeInsets
The minimum insets of the viewfinder.
getter/setter pairinherited
overlayColor ↔ ScanbotColor
The color of the viewfinder overlay.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ FinderStyle
The visual appearance of the viewfinder.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited