RangeEncoding class

A character encoding for a given range of bytes.

Constructors

RangeEncoding({required int start, required int end, required CharacterEncoding encoding})
RangeEncoding.fromJson(Map<String, dynamic> json)
factory

Properties

encoding → CharacterEncoding
Character encoding for the given range.
final
end → int
End index of the range (inclusive).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Start index of the range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited