RawImageLoadOptions class

Options for loading images that come from sensor.

Constructors

RawImageLoadOptions({Rectangle<int>? cropRect, ImageOrigin origin = ImageOrigin.TOP_LEFT, CanvasColor canvasColor = CanvasColor.WHITE, ImageRotation orientation = ImageRotation.NONE})
RawImageLoadOptions.fromJson(Map<String, dynamic> json)
factory

Properties

canvasColor ↔ CanvasColor
CanvasColor color to use when converting images with alpha channel to images without alpha channel.
getter/setter pair
cropRect ↔ Rectangle<int>
If the rect is not empty, the image will be cropped to this rect before processing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
orientation ↔ ImageRotation
Rotation that should be applied to the image to recover correct orientation. Is applied before cropping.
getter/setter pair
origin ↔ ImageOrigin
Location of the image origin in the image coordinate system. During loading images are flipped such that after the flip their new origin is in their top-left corner. For example, an image coming from the front camera might have its origin set to the top-right, which will flip it along its vertical axis to create a mirror effect.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited