orientation property
Rotation that should be applied to the image to recover correct orientation. Is applied before cropping.
Default is NONE.
Implementation
ImageRotation orientation;
Rotation that should be applied to the image to recover correct orientation. Is applied before cropping.
Default is NONE.
ImageRotation orientation;