RefCountedObjectProfile class

Profile info of a reference-counted stored object.

Constructors

RefCountedObjectProfile({required String uniqueId, required int timestampCreated, int strongReferences = 0, int serializedReferences = 0})
RefCountedObjectProfile.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serializedReferences → int
Number of serialized references to the object. The serialized reference count increases when an ImageRef is written to JSON or a Parcel on Android and decrease when the respective JSON or Parcel is deserialized.
final
strongReferences → int
Number of strong references associated with the object. The strong reference count increases when a new instance of a platform ImageRef class is created from the object's unique ID and decreases when the ImageRef instance is destroyed.
final
timestampCreated → int
Timestamp (milliseconds since the UNIX epoch), at which the object was first created.
final
uniqueId → String
Unique ID of the object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited