ResultWrapper<T> class

Constructors

ResultWrapper({required OperationStatus status, T? data, String? errorMessage})
ResultWrapper.error(String message)
factory
ResultWrapper.fromJson(Map<String, dynamic> json, {T fromJsonT(Map<String, dynamic>)?})
factory

Properties

data → T?
final
errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OperationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited