accessibilityState property
The text to be read to represent the current state of the button through accessibility mode.
Default is ""
Implementation
String accessibilityState;
The text to be read to represent the current state of the button through accessibility mode.
Default is ""
String accessibilityState;