SEPA class

SEPA

Inheritance

Constructors

SEPA(GenericDocument document)

Properties

amount → TextFieldWrapper?
Amount
no setter
characterSet → TextFieldWrapper
Character Set
no setter
document → GenericDocument
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
identification → TextFieldWrapper
Identification
no setter
information → TextFieldWrapper?
Information
no setter
purpose → TextFieldWrapper?
Amount
no setter
receiverBIC → TextFieldWrapper
Receiver BIC
no setter
receiverIBAN → TextFieldWrapper
Receiver IBAN
no setter
receiverName → TextFieldWrapper
Receiver Name
no setter
remittance → TextFieldWrapper?
Remittance
no setter
requiredDocumentType → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceTag → TextFieldWrapper
Service Tag
no setter
version → TextFieldWrapper
Version
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DOCUMENT_NORMALIZED_TYPE → const String
Normalized document type name of this document wrapper.
DOCUMENT_TYPE → const String
Generic document type name of this document wrapper.