SEPANormalizedFieldNames class

Constants for the field type names of SEPA.

Constructors

SEPANormalizedFieldNames()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

Amount → const String
CharacterSet → const String
Identification → const String
Information → const String
Purpose → const String
ReceiverBIC → const String
ReceiverIBAN → const String
ReceiverName → const String
Remittance → const String
ServiceTag → const String
Version → const String