ScanbotSdkConfig class

Scanbot SDK initialization config parameters.

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false, explicitToJson: true)

Constructors

ScanbotSdkConfig({String licenseKey = "", bool? loggingEnabled, bool? enableNativeLogging, String? storageBaseDirectory, dynamic licenseErrorHandler(SdkLicenseStatus)?, String? fileEncryptionPassword, FileEncryptionMode? fileEncryptionMode, bool? allowGpuAcceleration, bool? allowXnnpackAcceleration, bool? performanceHintApi})

Properties

allowGpuAcceleration ↔ bool?
If set to false, GPU Acceleration will be disabled for Barcode Scanner, Document Scanner and Generic Document Recognizer (Android only). Default is true.
getter/setter pair
allowXnnpackAcceleration ↔ bool?
If set to false, disables XNN pack optimizations (Android only). Default is true.
getter/setter pair
enableNativeLogging ↔ bool?
Optional boolean flag that enables Scanbot SDK Core native logging (default is false, Android only).
getter/setter pair
fileEncryptionMode ↔ FileEncryptionMode?
Length of the key in AES encryption - 128 or 256 bits
getter/setter pair
fileEncryptionPassword ↔ String?
A secure password or passphrase to derive the AES key for encryption/decryption
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
licenseErrorHandler ↔ dynamic Function(SdkLicenseStatus)?
Callback function to get info about problems with license key or concrete feature that is not available for usage
getter/setter pair
licenseKey ↔ String
Your license key for the Scanbot SDK.
getter/setter pair
loggingEnabled ↔ bool?
Optional logging flag. While it may be useful for development, consider switching logging OFF in production builds for security and performance reasons!
getter/setter pair
performanceHintApi ↔ bool?
If set to true, PerformanceHintApi is enabled, which lead to increase of performance due of increased use of top CPU cores (Android only), also increase battery usage. Default is true.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageBaseDirectory ↔ String?
Optional custom storage base directory. Can be nil.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited