SdkConfiguration class

Initialize configuration for the Scanbot SDK.

Constructors

SdkConfiguration({required String licenseKey, bool loggingEnabled = false, bool enableNativeLogging = false, String? storageBaseDirectory = null, FileEncryptionMode? fileEncryptionMode = null, String? fileEncryptionPassword = null, bool performanceHintApi = true, bool allowGpuAcceleration = true, bool allowXnnpackAcceleration = true, String? hibernationDirectory = null})
SdkConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

allowGpuAcceleration ↔ bool
If set to true, GPU Acceleration will be enabled for Barcode Scanner, Document Scanner and Generic Document Recognizer (Android only).
getter/setter pair
allowXnnpackAcceleration ↔ bool
Enables/disables XNNPACK acceleration for TensorFlow ML models, which provides highly optimized implementations of floating-point neural network operators (Android only).
getter/setter pair
enableNativeLogging ↔ bool
Optional boolean flag that enables Scanbot SDK Core native logging (default is false, Android only).
getter/setter pair
fileEncryptionMode ↔ FileEncryptionMode?
Optional file encryption mode, 'AES128' or 'AES256'.
getter/setter pair
fileEncryptionPassword ↔ String?
Optional file encryption password. Refer to the section "Storage Encryption" for more details.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hibernationDirectory ↔ String?
Optional directory as file URI for temporary on-disk storage of ImageRef image data. Hibernated images can later be restored as ImageRef instances.
getter/setter pair
licenseKey ↔ String
Your license key for the Scanbot SDK. See the "License Key" section below.
getter/setter pair
loggingEnabled ↔ bool
Optional boolean flag to enable logging. See the "Logging" section below.
getter/setter pair
performanceHintApi ↔ bool
If set to true, PerformanceHintApi is enabled, which lead to increase of performance due of increased use of top CPU cores (Android only), also increase battery usage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageBaseDirectory ↔ String?
Optional directory as file URI to override the default storage base directory of the Scanbot SDK. Refer to the section "Storage" for more details.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited