SdkLicenseStatus class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

SdkLicenseStatus(bool isLicenseValid, DateTime? licenseExpirationDate, LicenseStatus licenseStatus)
SdkLicenseStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLicenseValid ↔ bool
getter/setter pair
licenseExpirationDate ↔ DateTime?
getter/setter pair
licenseStatus ↔ LicenseStatus
getter/setter pair
licenseStatusMessage ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited