SheetContent class

Configuration of the list containing the barcodes that have already been scanned.

Constructors

SheetContent({ScanbotColor? sheetColor, ScanbotColor? dividerColor, bool manualCountChangeEnabled = true, ScanbotColor? manualCountOutlineColor, ScanbotColor? manualCountChangeColor, StyledText? title, ButtonConfiguration? clearAllButton, StyledText? barcodeItemTitle, StyledText? barcodeItemSubtitle, bool barcodeItemImageVisible = true, ButtonConfiguration? submitButton, ButtonConfiguration? startScanningButton, StyledText? placeholderTitle, StyledText? placeholderSubtitle, ScanbotColor? placeholderIconBackground, IconStyle? placeholderIcon, SwipeToDelete? swipeToDelete})
SheetContent.fromJson(Map<String, dynamic> json)
factory

Properties

barcodeItemImageVisible ↔ bool
Visibility of the barcode image in a barcode list entry.
getter/setter pair
barcodeItemSubtitle ↔ StyledText
Configuration of the subtitle of a barcode list entry (displaying the barcode's symbology).
getter/setter pair
barcodeItemTitle ↔ StyledText
Configuration of the title of a barcode list entry (displaying the barcode's value).
getter/setter pair
clearAllButton ↔ ButtonConfiguration
Configuration of the button for clearing the barcode list.
getter/setter pair
dividerColor ↔ ScanbotColor
The color of the dividers in the list sheet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualCountChangeColor ↔ ScanbotColor
Color of the buttons for manually changing the barcode count.
getter/setter pair
manualCountChangeEnabled ↔ bool
Enables the user to change the number of scanned items by pressing +,-, or changing the number using a keyboard.
getter/setter pair
manualCountOutlineColor ↔ ScanbotColor
The color of the outline of the manual counting buttons in the list sheet.
getter/setter pair
placeholderIcon ↔ IconStyle
Configuration of the icon displayed in an empty barcode list.
getter/setter pair
placeholderIconBackground ↔ ScanbotColor
Background color of the icon displayed in an empty barcode list.
getter/setter pair
placeholderSubtitle ↔ StyledText
Configuration of the subtitle displayed in an empty barcode list.
getter/setter pair
placeholderTitle ↔ StyledText
Configuration of the title displayed in an empty barcode list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetColor ↔ ScanbotColor
Color of the list's background.
getter/setter pair
startScanningButton ↔ ButtonConfiguration
Configuration of the button to start scanning displayed in an empty barcode list.
getter/setter pair
submitButton ↔ ButtonConfiguration
Configuration of the barcode list's submit button.
getter/setter pair
swipeToDelete ↔ SwipeToDelete
The style of the swipe-to-delete button.
getter/setter pair
title ↔ StyledText
Configuration of the barcode list's title. By default displays the total number of scanned barcodes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited