SingleScanningMode class

Configuration of the single barcode scanning mode.

Inheritance

Constructors

SingleScanningMode({bool confirmationSheetEnabled = false, bool barcodeImageVisible = true, ScanbotColor? sheetColor, ScanbotColor? dividerColor, ScanbotColor? modalOverlayColor, StyledText? barcodeTitle, StyledText? barcodeSubtitle, ButtonConfiguration? submitButton, ButtonConfiguration? cancelButton, BarcodeInfoMapping? barcodeInfoMapping, ArOverlayGeneralConfiguration? arOverlay})
SingleScanningMode.fromJson(Map<String, dynamic> json)
factory

Properties

arOverlay ↔ ArOverlayGeneralConfiguration
Configuration of the AR overlay.
getter/setter pair
barcodeImageVisible ↔ bool
If enabled, the barcode image will be shown on the confirmation sheet.
getter/setter pair
barcodeInfoMapping ↔ BarcodeInfoMapping
Appearance of the barcode info mapping.
getter/setter pair
barcodeSubtitle ↔ StyledText
Appearance of the barcode subtitle (the barcode's symbology) on the confirmation sheet.
getter/setter pair
barcodeTitle ↔ StyledText
Appearance of the barcode title (the barcode's value) on the confirmation sheet.
getter/setter pair
cancelButton ↔ ButtonConfiguration
Appearance of the cancel button on the confirmation sheet.
getter/setter pair
confirmationSheetEnabled ↔ bool
If enabled, the confirmation sheet will be shown after the barcode has been scanned.
getter/setter pair
dividerColor ↔ ScanbotColor
Color of the divider and separator lines in the confirmation sheet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modalOverlayColor ↔ ScanbotColor
Background color of the overlay surrounding the confirmation sheet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetColor ↔ ScanbotColor
Color of the confirmation sheet's background.
getter/setter pair
submitButton ↔ ButtonConfiguration
Appearance of the confirm button on the confirmation sheet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited