initialScanDelay property
Sets the length of time, in milliseconds, that the first scan will be delayed by. Default is 0 (disabled).
Default is 0.
Implementation
int initialScanDelay;
Sets the length of time, in milliseconds, that the first scan will be delayed by. Default is 0 (disabled).
Default is 0.
int initialScanDelay;