serializeImages property
Serialize images in the object to json. If false, then fields that contain images are not serialized.
Default is true.
Implementation
final bool serializeImages;
Serialize images in the object to json. If false, then fields that contain images are not serialized.
Default is true.
final bool serializeImages;