TwoDDecodingMode enum

Allows to select the decoding effort to be spent on decoding 2D barcodes. Higher decoding efforts can decode barcodes that are more damaged or have a lower print quality or are printed on non-ideal surfaces (e.g. curved surfaces). However, higher decoding efforts also require more processing time.

Inheritance
Available extensions

Values

LOW_EFFORT → const TwoDDecodingMode

Fast decoding mode. This mode provides the fastest decoding speed, but is less likely to decode damaged or low-quality barcodes. Can be used for high-frame-rate scanning where most barcodes are expected to be in good condition or on low processing power devices.

HIGH_EFFORT → const TwoDDecodingMode

High-effort decoding mode. This mode provides the highest decoding success rate for damaged or low-quality barcodes, at the cost of a slower decoding speed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TwoDDecodingMode>
A constant List of the values in this enum, in order of their declaration.