UserGuidanceConfiguration class

Configuration of the hint guiding users through the scanning process.

Constructors

UserGuidanceConfiguration({bool visible = true, StyledText? title, BackgroundStyle? background})
UserGuidanceConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

background ↔ BackgroundStyle
The background style used for the user guidance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ StyledText
The title of the user guidance.
getter/setter pair
visible ↔ bool
Determines whether the user guidance is visible or not.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited