VCardEntry class abstract

VCard Entry

Inheritance
Implementers

Constructors

VCardEntry(GenericDocument document)

Properties

document → GenericDocument
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
rawValue → TextFieldWrapper
Raw Value
no setter
requiredDocumentType → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeModifiers → List<TextFieldWrapper>
Type Modifier
no setter
values → List<TextFieldWrapper>
Value
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited