ValidatedTextFieldWrapper class

Text field wrapper

Inheritance

Constructors

ValidatedTextFieldWrapper(Field field)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ FieldType
Field type
getter/setter pairinherited
validated ↔ bool
Field text value
getter/setter pair
value ↔ OcrResult?
Field text value
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited