enabled property
Determine whether vibration should be enabled or not when a barcode is detected.
Default is false.
Implementation
bool enabled;
Determine whether vibration should be enabled or not when a barcode is detected.
Default is false.
bool enabled;