ZoomRange class

Defines a range for zooming

Constructors

ZoomRange({required double minZoom, required double maxZoom})
ZoomRange.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxZoom ↔ double
The maximum zoom scale. Defaults to 12.0.
getter/setter pair
minZoom ↔ double
The minimum zoom scale. Defaults to 1.0.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited