ScanbotBarcodeSdk class

Entry point for all features that are part of Scanbot Barcode Scanner SDK.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

barcode ↔ ScanbotBarcode
Used for barcode scanning features.
getter/setter pair
imageProcessor ↔ ScanbotImageProcessor
Used for image processing features.
getter/setter pair

Static Methods

cleanupStorage() → Future<Result<void>>
Cleans up the storage used by the Scanbot SDK.
getLicenseInfo() → Future<Result<LicenseInfo>>
Provides complete information about the current license.
initialize(SdkConfiguration configuration) → Future<Result<LicenseInfo>>
Initializes the Scanbot SDK with the preferred configuration.
mockCamera(String imageFileUri, {bool? refreshOnEachFrame}) → Future<Result<void>>
Mock camera preview by using static images as a frame source. This is useful for testing purposes.