AdaptiveBarButtonConfiguration class
Configuration of the button dynamically located on a bar or in a popup menu.
Constructors
- AdaptiveBarButtonConfiguration({BarButtonConfiguration? barButton, PopupMenuItem? popupMenuItem})
-
AdaptiveBarButtonConfiguration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- barButton ↔ BarButtonConfiguration
-
Configuration of the button located on a bar.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- popupMenuItem ↔ PopupMenuItem
-
Configuration of the item located in the popup menu.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{ToJsonConfiguration? config}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited