BarcodeScannerCamera class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BarcodeScannerCamera
Constructors
-
BarcodeScannerCamera({Key? key, required BarcodeCameraConfiguration configuration, dynamic onCameraPreviewStarted(bool isFlashAvailable)?, dynamic barcodeListener(List<
BarcodeItem> result)?, Future<void> onPictureTaken(ImageRef image)?, dynamic onError(SBException error)?, BarcodeScannerCameraController? controller}) -
const
Properties
-
barcodeListener
→ dynamic Function(List<
BarcodeItem> result)? -
The callback that will be called each time barcodes is detected.
final
- configuration → BarcodeCameraConfiguration
-
The configuration of the camera and detection behavior.
final
- controller → BarcodeScannerCameraController?
-
The controller to access the camera methods.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCameraPreviewStarted → dynamic Function(bool isFlashAvailable)?
-
Runs each time the camera preview is started.
final
- onError → dynamic Function(SBException error)?
-
The callback that will be called when there is any error.
final
-
onPictureTaken
→ Future<
void> Function(ImageRef image)? -
The callback that will be called each time the picture is taken.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited