CameraConfiguration class

Configuration of the camera settings to be used while scanning.

Constructors

CameraConfiguration({CameraModule cameraModule = CameraModule.BACK, List<double>? zoomSteps, double defaultZoomFactor = 1.0, bool flashEnabled = false, bool minFocusDistanceLock = false, bool touchToFocusEnabled = false, bool pinchToZoomEnabled = true, OrientationLockMode orientationLockMode = OrientationLockMode.NONE, CameraPreviewMode cameraPreviewMode = CameraPreviewMode.FILL_IN, CameraPreviewAspectRatio? cameraPreviewAspectRatio = null, bool hardwareButtonsEnabled = true, int fpsLimit = 20, CameraLiveScannerResolution cameraLiveScannerResolution = CameraLiveScannerResolution.FULL_HD})
CameraConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

cameraLiveScannerResolution CameraLiveScannerResolution
The size of the image from camera which would be sent to the scanner for live scanning.
getter/setter pair
cameraModule CameraModule
Determines which camera module to use on start-up.
getter/setter pair
cameraPreviewAspectRatio CameraPreviewAspectRatio?
Tries to select the camera preview aspect ratio that best matches the given aspect ratio. If no exact match is found, it selects the closest one available. Android only.
getter/setter pair
cameraPreviewMode CameraPreviewMode
Determines which camera preview mode to use.
getter/setter pair
defaultZoomFactor double
The default zoom factor on start-up.
getter/setter pair
flashEnabled bool
Determines whether the flash is enabled on start-up.
getter/setter pair
fpsLimit int
The rate of detections/recognitions per second in normal performance mode. If the number is equal or greater than the video frame rate, no frames will be skipped.
getter/setter pair
hardwareButtonsEnabled bool
When enabled it allows zooming using camera control button (iPhone 16 series). iOS only.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
minFocusDistanceLock bool
Determines whether to lock the focus at the minimum possible distance (device-specific).
getter/setter pair
orientationLockMode OrientationLockMode
Determines which mode to use when orientation should be locked to landscape or portrait.
getter/setter pair
pinchToZoomEnabled bool
Determines whether pinch-to-zoom is enabled or not.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
touchToFocusEnabled bool
Determines whether touch-to-focus is enabled or not.
getter/setter pair
zoomSteps List<double>
The zoom steps available to the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ToJsonConfiguration? config}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited