optimize property
If true, the encoder will spend extra time when saving JPEG files
to improve the compression rate. Enabling this option has no impact on quality.
Default is false
Implementation
bool optimize;
If true, the encoder will spend extra time when saving JPEG files
to improve the compression rate. Enabling this option has no impact on quality.
Default is false
bool optimize;