activeAccessibilityState property
The text to be read to represent the current state of the button when the button is active (selected, toggled) through accessibility mode.
Default is ""
Implementation
String activeAccessibilityState;
The text to be read to represent the current state of the button when the button is active (selected, toggled) through accessibility mode.
Default is ""
String activeAccessibilityState;