SaveImageOptions class
Options for saving image to a path.
Constructors
- SaveImageOptions({int quality = -1, bool optimize = false, EncryptionMode encryptionMode = EncryptionMode.AUTO})
-
SaveImageOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- encryptionMode ↔ EncryptionMode
-
Encryption mode.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- optimize ↔ bool
-
If
true, the encoder will spend extra time when saving JPEG files to improve the compression rate. Enabling this option has no impact on quality.getter/setter pair - quality ↔ int
-
Quality parameter is for JPEG only and is in range 0 to 100. If -1, then the value from hibernation is used.
In case the ImageRef was created in lazy load-mode and originally has the same format as the requested to save,
then setting quality to -1 leads to simply copying from source to destination,
which is time efficient and prevents quality loss caused by decoding the JPEG and then re-encoding it.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{ToJsonConfiguration? config}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited